jdk/src/java.base/share/classes/java/lang/Class.java
changeset 37782 ad8fe7507ecc
parent 37363 329dba26ffd2
child 38951 077499b63957
--- a/jdk/src/java.base/share/classes/java/lang/Class.java	Tue May 03 15:50:54 2016 +0200
+++ b/jdk/src/java.base/share/classes/java/lang/Class.java	Tue May 03 10:40:54 2016 -0700
@@ -470,7 +470,7 @@
      * expression with an empty argument list.  The class is initialized if it
      * has not already been initialized.
      *
      * <p>Note that this method propagates any exception thrown by the
      * nullary constructor, including a checked exception.  Use of
      * this method effectively bypasses the compile-time exception
      * checking that would otherwise be performed by the compiler.
@@ -500,6 +500,7 @@
      *          of this class.
      */
     @CallerSensitive
+    @Deprecated(since="9")
     public T newInstance()
         throws InstantiationException, IllegalAccessException
     {
@@ -470,7 +470,7 @@
      * has not already been initialized.
      *
-     * <p>Note that this method propagates any exception thrown by the
+     * @deprecated This method propagates any exception thrown by the
      * nullary constructor, including a checked exception.  Use of
      * this method effectively bypasses the compile-time exception